@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# Copyright (c) 2018, 2019  Peter Pentchev
+# Copyright (c) 2018, 2019, 2021  Peter Pentchev
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -34,7 +34,7 @@ use JSON::XS;
 use POSIX qw(dup2);
 
 my $debug = 0;
-my $version = '0.2.2';
+my $version = '1.0.1';
 my $default_option = '--features';
 my $default_prefix = 'Features: ';
 my $default_output_fmt = 'tsv';
@@ -269,7 +269,7 @@ sub version_compare_split($ $)
 	if ($na ne '') {
 		if ($nb ne '') {
 			if ($nb != $na) {
-				return $na cmp $nb;
+				return $na <=> $nb;
 			}
 		} else {
 			return 1;
@@ -282,7 +282,7 @@ sub version_compare_split($ $)
 	if ($ra ne '') {
 		if ($rb ne '') {
 			if ($ra ne $rb) {
-				return $ra <=> $rb;
+				return $ra cmp $rb;
 			}
 		} else {
 			return 1;
